@@ -985,9 +985,9 @@ mod param_tests {
         }
     }
 
-    impl Into<ErrWrapper> for Error {
-        fn into(self) -> ErrWrapper {
-            ErrWrapper(self)
+    impl From<Error> for ErrWrapper {
+        fn from(error: Error) -> Self {
+            ErrWrapper(error)
         }
     }
 
